@@ -1,4 +1,4 @@
-# Copyright 2016-2021 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -7,13 +7,13 @@
 # LSF backend
 #
 # - Initial version submitted by Ryan Goodner, UNM (based on PBS backend)
+# - Extended and fixed by Jonathan Frawley and Mark Turner
 #
 
 import functools
 import re
 import time
 
-import reframe.core.runtime as rt
 import reframe.utility.osext as osext
 from reframe.core.backends import register_scheduler
 from reframe.core.exceptions import JobSchedulerError
@@ -26,49 +26,62 @@ _run_strict = functools.partial(osext.run_command, check=True)
 class LsfJobScheduler(PbsJobScheduler):
     def __init__(self):
         self._prefix = '#BSUB'
-        self._submit_timeout = rt.runtime().get_option(
-            f'schedulers/@{self.registered_name}/job_submit_timeout'
-        )
+        self._submit_timeout = self.get_option('job_submit_timeout')
+
+    def _format_option(self, var, option):
+        if var is not None:
+            return self._prefix + ' ' + option.format(var)
+        else:
+            return ''
 
     def emit_preamble(self, job):
-        num_tasks_per_node = job.num_tasks_per_node or 1
-        num_nodes = job.num_tasks // num_tasks_per_node
-
         preamble = [
-            self._format_option(f'-J {job.name}'),
-            self._format_option(f'-o {job.stdout}'),
-            self._format_option(f'-e {job.stderr}'),
-            self._format_option(f'-nnodes {num_nodes}')
+            self._format_option(job.name, '-J {0}'),
+            self._format_option(job.stdout, '-o {0}'),
+            self._format_option(job.stderr, '-e {0}'),
         ]
 
+        if job.num_tasks_per_node is not None:
+            num_nodes = job.num_tasks // job.num_tasks_per_node
+            preamble.append(self._format_option(num_nodes, '-nnodes {0}'))
+        else:
+            preamble.append(self._format_option(job.num_tasks, '-n {0}'))
+
+        if job.num_cpus_per_task is not None:
+            preamble.append(self._format_option(job.num_cpus_per_task,
+                                                '-R "affinity[core({0})]"'))
+
         # add job time limit in minutes
         if job.time_limit is not None:
             preamble.append(
-                self._format_option(f'-W {int(job.time_limit // 60)}')
+                f'{self._prefix} -W {int(job.time_limit // 60)}'
             )
 
+        for opt in job.sched_access:
+            preamble.append(f'{self._prefix} {opt}')
+
         # emit the rest of the options
         options = job.options + job.cli_options
         for opt in options:
             if opt.startswith('#'):
                 preamble.append(opt)
             else:
-                preamble.append(self._format_option(opt))
+                preamble.append(self._prefix + ' ' + opt)
 
-        # change to working dir with cd
-        preamble.append(f'cd {job.workdir}')
+        if job.exclusive_access:
+            preamble.append(f'{self._prefix} -x')
 
-        return preamble
+        # Filter out empty statements before returning
+        return list(filter(None, preamble))
 
     def submit(self, job):
-        cmd = f'bsub {job.script_filename}'
-        completed = _run_strict(cmd, timeout=self._submit_timeout)
+        with open(job.script_filename, 'r') as fp:
+            completed = _run_strict('bsub', stdin=fp)
         jobid_match = re.search(r'^Job <(?P<jobid>\S+)> is submitted',
                                 completed.stdout)
         if not jobid_match:
             raise JobSchedulerError('could not retrieve the job id '
                                     'of the submitted job')
-
         job._jobid = jobid_match.group('jobid')
         job._submit_time = time.time()
 
