@@ -23,14 +23,14 @@ def _have_name(patt):
         # Match pattern, but remove spaces from the `display_name`
         display_name = case.check.display_name.replace(' ', '')
         rt = runtime()
-        if not rt.get_option('general/0/compact_test_names'):
-            return regex.match(case.check.unique_name)
+        if '@' in patt:
+            # Do an exact match on the unique name
+            return patt.replace('@', '_') == case.check.unique_name
+        elif patt.startswith('/'):
+            # Do an exact match on the hashcode
+            return patt[1:] == case.check.hashcode
         else:
-            if '@' in patt:
-                # Do an exact match on the unique name
-                return patt.replace('@', '_') == case.check.unique_name
-            else:
-                return regex.match(display_name)
+            return regex.match(display_name)
 
     return _fn
 
@@ -44,15 +44,16 @@ def have_not_name(patt):
 
 def have_any_name(names):
     rt = runtime()
-    has_compact_names = rt.get_option('general/0/compact_test_names')
-    exact_matches = []
+    variant_matches = []
+    hash_matches = []
     regex_matches = []
     for n in names:
-        if has_compact_names and '@' in n:
+        if '@' in n:
             test, _, variant = n.rpartition('@')
             if variant.isdigit():
-                exact_matches.append((test, int(variant)))
-
+                variant_matches.append((test, int(variant)))
+        elif n.startswith('/'):
+            hash_matches.append(n[1:])
         else:
             regex_matches.append(n)
 
@@ -62,18 +63,20 @@ def have_any_name(names):
         regex = None
 
     def _fn(case):
-        # Check if we have an exact match
-        for m in exact_matches:
+        # Check the variant matches
+        for m in variant_matches:
             cls_name = type(case.check).__name__
             if (cls_name, case.check.variant_num) == m:
                 return True
 
+        # Check hash matches
+        for m in hash_matches:
+            if m == case.check.hashcode:
+                return True
+
         display_name = case.check.display_name.replace(' ', '')
         if regex:
-            if has_compact_names:
-                return regex.match(display_name)
-            else:
-                return regex.match(case.check.unique_name)
+            return regex.match(display_name)
 
         return False
 
